==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/acl/lang/pt-br/lang.php <==
<?php
/**
 * Brazilian Portuguese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Luis Fernando Enciso <lfenciso@certto.com.br>
 * @author Alauton/Loug
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 * @author Jair Henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luisdantas@gmail.com>
 * @author Sergio Motta sergio@cisne.com.br
 * @author Isaias Masiero Filho <masiero@masiero.org>
 * @author Balaco Baco <balacobaco@imap.cc>
 * @author Victor Westmann <victor.westmann@gmail.com>
 */
$lang['admin_acl']             = 'Administração da Lista de Controles de Acesso';
$lang['acl_group']             = 'Grupo';
$lang['acl_user']              = 'Usuário';
$lang['acl_perms']             = 'Permissões para';
$lang['page']                  = 'Página';
$lang['namespace']             = 'Espaço de nomes';
$lang['btn_select']            = 'Selecionar';
$lang['p_user_id']             = 'O usuário <b class="acluser">%s</b> possui as seguintes permissões na página <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'O usuário <b class="acluser">%s</b> possui as seguintes permissões no espaço de nomes <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Os membros do grupo <b class="aclgroup">%s</b> possuem as seguintes permissões na página <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Os membros do grupo <b class="aclgroup">%s</b> possuem as seguintes permissões no espaço de nomes <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Por favor <b>digite um usuário ou grupo</b> no formulário acima para ver ou editar as permissões para a página <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Por favor <b>digite um usuário ou grupo</b> no formulário acima para ver ou editar as permissões para o espaço de nomes <b class="aclpage">%s</b>.';
$lang['p_inherited']           = 'Nota: Essas permissões não foram definidas explicitamente, mas sim herdadas de outros grupos ou espaço de nomes superiores.';
$lang['p_isadmin']             = 'Nota: O grupo ou usuário selecionado sempre tem permissões completas, porque ele está configurado como superusuário.';
$lang['p_include']             = 'As permissões superiores incluem as inferiores. Permissões para Criar, Enviar e Apagar aplicam-se apenas aos espaços de nomes e não às páginas.';
$lang['current']               = 'Regras atuais da ACL';
$lang['where']                 = 'Página/Espaço de nomes';
$lang['who']                   = 'Usuário/Grupo';
$lang['perm']                  = 'Permissões';
$lang['acl_perm0']             = 'Nenhuma';
$lang['acl_perm1']             = 'Ler';
$lang['acl_perm2']             = 'Editar';
$lang['acl_perm4']             = 'Criar';
$lang['acl_perm8']             = 'Enviar';
$lang['acl_perm16']            = 'Excluir';
$lang['acl_new']               = 'Adicionar nova entrada';
$lang['acl_mod']               = 'Modificar a entrada';

==> dokuwiki-2015.08.10a.tgz: dokuwiki/lib/plugins/acl/lang/pt-br/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Luis Fernando Enciso <lfenciso@certto.com.br>
 * @author Alauton/Loug
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 * @author Jair Henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luisdantas@gmail.com>
 * @author Sergio Motta sergio@cisne.com.br
 * @author Isaias Masiero Filho <masiero@masiero.org>
 * @author Balaco Baco <balacobaco@imap.cc>
 * @author Victor Westmann <victor.westmann@gmail.com>
 */
$lang['admin_acl']             = 'Administração da Lista de Controles de Acesso';
$lang['acl_group']             = 'Grupo:';
$lang['acl_user']              = 'Usuário:';
$lang['acl_perms']             = 'Permissões para';
$lang['page']                  = 'Página';
$lang['namespace']             = 'Espaço de nomes';
$lang['btn_select']            = 'Selecionar';
$lang['p_user_id']             = 'O usuário <b class="acluser">%s</b> possui as seguintes permissões na página <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'O usuário <b class="acluser">%s</b> possui as seguintes permissões no espaço de nomes <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Os membros do grupo <b class="aclgroup">%s</b> possuem as seguintes permissões na página <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Os membros do grupo <b class="aclgroup">%s</b> possuem as seguintes permissões no espaço de nomes <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Por favor <b>digite um usuário ou grupo</b> no formulário acima para ver ou editar as permissões para a página <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Por favor <b>digite um usuário ou grupo</b> no formulário acima para ver ou editar as permissões para o espaço de nomes <b class="aclpage">%s</b>.';
$lang['p_inherited']           = 'Nota: Essas permissões não foram definidas explicitamente, mas sim herdadas de outros grupos ou espaço de nomes superiores.';
$lang['p_isadmin']             = 'Nota: O grupo ou usuário selecionado sempre tem permissões completas, porque ele está configurado como superusuário.';
$lang['p_include']             = 'As permissões superiores incluem as inferiores. Permissões para Criar, Enviar e Apagar aplicam-se apenas aos espaços de nomes e não às páginas.';
$lang['current']               = 'Regras atuais da ACL';
$lang['where']                 = 'Página/Espaço de nomes';
$lang['who']                   = 'Usuário/Grupo';
$lang['perm']                  = 'Permissões';
$lang['acl_perm0']             = 'Nenhuma';
$lang['acl_perm1']             = 'Ler';
$lang['acl_perm2']             = 'Editar';
$lang['acl_perm4']             = 'Criar';
$lang['acl_perm8']             = 'Enviar';
$lang['acl_perm16']            = 'Excluir';
$lang['acl_new']               = 'Adicionar nova entrada';
$lang['acl_mod']               = 'Modificar a entrada';
